@@ -1,9 +1,8 @@
-# Copyright (c) 2018 Siphon Contributors.
+# Copyright (c) 2018,2019 Siphon Contributors.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 """Read upper air data from the Integrated Global Radiosonde Archive version 2."""
 
-from contextlib import closing
 import datetime
 from io import BytesIO
 from io import StringIO
@@ -16,27 +15,29 @@ import numpy as np
 import pandas as pd
 
 from .._tools import get_wind_components
+from ..http_util import HTTPEndPoint, HTTPError
 
-warnings.filterwarnings('ignore', 'Pandas doesn\'t allow columns to be created', UserWarning)
+warnings.filterwarnings('ignore', "Pandas doesn't allow columns to be created", UserWarning)
 
 
-class IGRAUpperAir:
+class IGRAUpperAir(HTTPEndPoint):
     """Download and parse data from NCEI's Integrated Radiosonde Archive version 2."""
 
     def __init__(self):
-        """Set ftp site address and file suffix based on desired dataset."""
-        self.ftpsite = 'ftp://ftp.ncdc.noaa.gov/pub/data/igra/'
+        """Set http site address and file suffix based on desired dataset."""
         self.suffix = ''
         self.begin_date = ''
         self.end_date = ''
         self.site_id = ''
+        self.folder = ''
+        super(IGRAUpperAir, self).__init__('https://www1.ncdc.noaa.gov/pub/data/igra/')
 
     @classmethod
     def request_data(cls, time, site_id, derived=False):
         """Retreive IGRA version 2 data for one station.
 
         Parameters
-        --------
+        ----------
         site_id : str
             11-character IGRA2 station identifier.
 
@@ -53,10 +54,10 @@ class IGRAUpperAir:
 
         # Set parameters for data query
         if derived:
-            igra2.ftpsite = igra2.ftpsite + 'derived/derived-por/'
+            igra2.folder = 'derived/derived-por/'
             igra2.suffix = igra2.suffix + '-drvd.txt'
         else:
-            igra2.ftpsite = igra2.ftpsite + 'data/data-por/'
+            igra2.folder = 'data/data-por/'
             igra2.suffix = igra2.suffix + '-data.txt'
 
         if type(time) == datetime.datetime:
@@ -74,10 +75,11 @@ class IGRAUpperAir:
     def _get_data(self):
         """Process the IGRA2 text file for observations at site_id matching time.
 
-        Return:
+        Returns
         -------
             :class: `pandas.DataFrame` containing the body data.
             :class: `pandas.DataFrame` containing the header data.
+
         """
         # Split the list of times into begin and end dates. If only
         # one date is supplied, set both begin and end dates equal to that date.
@@ -102,15 +104,18 @@ class IGRAUpperAir:
         Returns a tuple with a string for the body, string for the headers,
         and a list of dates.
         """
-        # Import need to be here so we can monkeypatch urlopen for testing and avoid
-        # downloading live data for testing
-        try:
-            from urllib.request import urlopen
-        except ImportError:
-            from urllib2 import urlopen
+        path = self.folder + self.site_id + self.suffix + '.zip'
 
-        with closing(urlopen(self.ftpsite + self.site_id + self.suffix + '.zip')) as url:
-            f = ZipFile(BytesIO(url.read()), 'r').open(self.site_id + self.suffix)
+        # Get the data and handle if there is none matching what was requested
+        try:
+            resp = self.get_path(path)
+        except HTTPError:
+            raise ValueError('No data available for {time:%Y-%m-%d %HZ} '
+                             'for station {stid}.'.format(time=self.begin_date,
+                                                          stid=self.site_id))
+
+        file_info = ZipFile(BytesIO(resp.content)).infolist()[0]
+        f = ZipFile(BytesIO(resp.content)).open(file_info)
 
         lines = [line.decode('utf-8') for line in f.readlines()]
 
@@ -122,7 +127,7 @@ class IGRAUpperAir:
         """Identify lines containing headers within the range begin_date to end_date.
 
         Parameters
-        -----
+        ----------
         lines: list
             list of lines from the IGRA2 data file.
 
@@ -163,10 +168,10 @@ class IGRAUpperAir:
         selector = np.zeros(len(lines), dtype=bool)
         selector[begin_idx:end_idx + 1] = True
         selector[headers] = False
-        body = ''.join([line for line in itertools.compress(lines, selector)])
+        body = ''.join(itertools.compress(lines, selector))
 
         selector[begin_idx:end_idx + 1] = ~selector[begin_idx:end_idx + 1]
-        header = ''.join([line for line in itertools.compress(lines, selector)])
+        header = ''.join(itertools.compress(lines, selector))
 
         # expand date vector to match length of the body dataframe.
         dates_long = np.repeat(dates, num_lev)
@@ -232,8 +237,9 @@ class IGRAUpperAir:
                           'potential_temperature_gradient', 'virtual_temperature',
                           'virtual_potential_temperature', 'vapor_pressure',
                           'saturation_vapor_pressure', 'reported_relative_humidity',
-                          'calculated_relative_humidity', 'u_wind', 'u_wind_gradient',
-                          'v_wind', 'v_wind_gradient', 'refractive_index']
+                          'calculated_relative_humidity', 'relative_humidity_gradient',
+                          'u_wind', 'u_wind_gradient', 'v_wind', 'v_wind_gradient',
+                          'refractive_index']
 
             colspecs_body = [(0, 7), (8, 15), (16, 23), (24, 31), (32, 39),
                              (40, 47), (48, 55), (56, 63), (64, 71), (72, 79),
@@ -253,6 +259,7 @@ class IGRAUpperAir:
                          'saturation_vapor_pressure': _cdec(power=3),
                          'reported_relative_humidity': _cdec(),
                          'calculated_relative_humidity': _cdec(),
+                         'relative_humidity_gradient': _cdec(),
                          'u_wind': _cdec(),
                          'u_wind_gradient': _cdec(),
                          'v_wind': _cdec(),
@@ -374,6 +381,7 @@ class IGRAUpperAir:
                         'saturation_vapor_pressure': 'Pascal',
                         'reported_relative_humidity': 'percent',
                         'calculated_relative_humidity': 'percent',
+                        'relative_humidity_gradient': 'percent / kilometer',
                         'u_wind': 'meter / second',
                         'u_wind_gradient': '(meter / second) / kilometer)',
                         'v_wind': 'meter / second',
